# ifndef yySemantic
# define yySemantic

# if defined __STDC__ | defined __cplusplus
# define ARGS(parameters)	parameters
# else
# define ARGS(parameters)	()
# endif

# ifndef rbool
# define rbool char
# endif

# include "Tree.h"
# include "Definitions.h"


extern void (* Semantic_Exit) ARGS ((void));

extern void Semantic ARGS ((tTree t));

extern void BeginSemantic ARGS ((void));
extern void CloseSemantic ARGS ((void));

# endif
